@@ -414,6 +414,9 @@ xfdesktop_load_icon_from_desktop_file(XfdesktopRegularFileIcon *regular_icon)
         gchar *tmp_name = NULL;
         gchar *p = strrchr(icon_name, '.');
 
+        if(!(g_strcmp0(p, ".png") == 0 || g_strcmp0(p, ".xpm") == 0 || g_strcmp0(p, ".svg") == 0))
+            p = NULL;
+
         if(p != NULL)
             tmp_name = g_strndup(icon_name, p - icon_name);
         else
@@ -814,7 +817,8 @@ xfdesktop_regular_file_icon_peek_tooltip(XfdesktopIcon *icon)
         time_string = xfdesktop_file_utils_format_time_for_display(mtime);
 
         regular_file_icon->priv->tooltip =
-            g_strdup_printf(_("Type: %s\nSize: %s\nLast modified: %s"),
+            g_strdup_printf(_("Name: %s\nType: %s\nSize: %s\nLast modified: %s"),
+                            regular_file_icon->priv->display_name,
                             description, size_string, time_string);
 
         /* Extract the Comment entry from the .desktop file */
