@@ -96,7 +96,7 @@ static GFile *xfdesktop_volume_icon_peek_file(XfdesktopFileIcon *icon);
 static void xfdesktop_volume_icon_update_file_info(XfdesktopFileIcon *icon,
                                                    GFileInfo *info);
 static gboolean xfdesktop_volume_icon_activated(XfdesktopIcon *icon);
-static gboolean volume_icon_changed_timeout(XfdesktopVolumeIcon *icon);
+static gboolean volume_icon_changed_timeout(gpointer user_data);
 static void xfdesktop_volume_icon_changed(GVolume *volume,
                                           XfdesktopVolumeIcon *volume_icon);
 
@@ -146,8 +146,6 @@ xfdesktop_volume_icon_class_init(XfdesktopVolumeIconClass *klass)
     file_icon_class->peek_filesystem_info = xfdesktop_volume_icon_peek_filesystem_info;
     file_icon_class->peek_file = xfdesktop_volume_icon_peek_file;
     file_icon_class->update_file_info = xfdesktop_volume_icon_update_file_info;
-    file_icon_class->can_rename_file = (gboolean (*)(XfdesktopFileIcon *))gtk_false;
-    file_icon_class->can_delete_file = (gboolean (*)(XfdesktopFileIcon *))gtk_false;
 }
 
 static void
@@ -807,7 +805,7 @@ xfdesktop_volume_icon_populate_context_menu(XfdesktopIcon *icon,
 
     icon_name = "document-open";
 
-    img = gtk_image_new_from_icon_name("document-open", GTK_ICON_SIZE_MENU);
+    img = gtk_image_new_from_icon_name(icon_name, GTK_ICON_SIZE_MENU);
     mi = xfdesktop_menu_create_menu_item_with_mnemonic(_("_Open"), img);
     gtk_widget_show(mi);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
@@ -821,8 +819,34 @@ xfdesktop_volume_icon_populate_context_menu(XfdesktopIcon *icon,
     mount = g_volume_get_mount(volume);
 
     if(mount && g_volume_can_eject(volume)) {
+        GDrive              *drive;
+        GDriveStartStopType  start_stop_type = G_DRIVE_START_STOP_TYPE_UNKNOWN;
+
+        drive = g_volume_get_drive (volume);
+        if (drive != NULL)
+          {
+            start_stop_type = g_drive_get_start_stop_type (drive);
+            g_object_unref (drive);
+          }
+
+        switch (start_stop_type)
+          {
+          case G_DRIVE_START_STOP_TYPE_SHUTDOWN:
+            icon_label = _("_Safely Remove Volume");
+            break;
+          case G_DRIVE_START_STOP_TYPE_NETWORK:
+            icon_label = _("_Disconnect Volume");
+            break;
+          case G_DRIVE_START_STOP_TYPE_MULTIDISK:
+            icon_label = _("_Stop the Multi-Disk Drive");
+            break;
+          case G_DRIVE_START_STOP_TYPE_PASSWORD:
+            icon_label = _("_Lock Volume");
+            break;
+          default:
+            icon_label = _("E_ject Volume");
+          }
         icon_name = "media-eject";
-        icon_label = _("E_ject Volume");
         xfdesktop_volume_icon_add_context_menu_option(icon, icon_name, icon_label,
                         menu, G_CALLBACK(xfdesktop_volume_icon_menu_eject));
     }
@@ -951,8 +975,9 @@ xfdesktop_volume_icon_activated(XfdesktopIcon *icon_p)
 }
 
 static gboolean
-volume_icon_changed_timeout(XfdesktopVolumeIcon *volume_icon)
+volume_icon_changed_timeout(gpointer user_data)
 {
+    XfdesktopVolumeIcon *volume_icon = user_data;
     GMount *mount;
     gboolean mounted_before = FALSE;
     gboolean mounted_after = FALSE;
@@ -1062,7 +1087,7 @@ xfdesktop_volume_icon_changed(GVolume *volume,
     volume_icon->priv->changed_timeout_count = 0;
     volume_icon->priv->changed_timeout_id =
         g_timeout_add_full(G_PRIORITY_LOW, 500,
-                           (GSourceFunc) volume_icon_changed_timeout,
+                           volume_icon_changed_timeout,
                            g_object_ref(volume_icon),
                            g_object_unref);
 }
